function [ Laplacepsi] = Laplace2s( x,y,z,xi,yi,zi,Z,a0 )
%
% This function calculates the Laplace Operation on the 2s Atomic orbital
%
% function [ Laplacepsi ] = Laplace2s(x,y,z,xi,yi,zi,Z,a0 )
%
% Laplacepsi       	result of the Laplace transformation
% x                 values for the x-direction
% y                 values for the y-direction
% z                 values for the z-direction
% xi                values for the 
% yi                values for the 
% zi                values for the 
% Z                 Atomic number 
% a0                Bohr radius

hallo = 0;

%% Define r
% r is the radius and can be calculated with the definition of spherical
% coordinates

r = sqrt((x-xi)^2+(y-yi)^2+(z-zi)^2);

%% Result
%
% The formular for the Laplacian transformation has been calculated by hand

Laplacepsi = 0.25*sqrt(Z^5/(2*pi*a0^5)).*(-Z^2*r/(4*a0^2)+5*Z/(2*a0)-4./r).*exp(-Z*r/(2*a0));


end

